/* 
 * PPRacer 
 * Copyright (C) 2004 Volker Stroebel <volker@planetpenguin.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


#include "configuration.h"

#include "gl_util.h"

#include "fonts.h"

#include "ppgltk/button.h"
#include "ppgltk/ui_mgr.h"
#include "ppgltk/ui_snow.h"
#include "ppgltk/audio/audio.h"

#include "render_util.h"
#include "game_config.h"

static game_mode_t preConfigMode = NO_MODE;


Configuration::Configuration()
{
	if(GameMode::prevmode==GAME_TYPE_SELECT || GameMode::prevmode == PAUSED){
		preConfigMode = GameMode::prevmode;
	}
	
	mp_heading = _("Configuration");
	
	pp::Vec2d pos(0,0);
	
	mp_graphicsBtn = new pp::Button(pos,
				     pp::Vec2d(300, 40),
				     "button_label",
				     _("Graphics") );
    mp_graphicsBtn->setHilitFontBinding( "button_label_hilit" );
    mp_graphicsBtn->signalClicked.Connect(pp::CreateSlot(this,&Configuration::graphics));
	
	mp_videoBtn = new pp::Button(pos,
				     pp::Vec2d(300, 40), 
				     "button_label", 
				     _("Video") );
    mp_videoBtn->setHilitFontBinding( "button_label_hilit" );
	mp_videoBtn->signalClicked.Connect(pp::CreateSlot(this,&Configuration::video));	

	mp_audioBtn = new pp::Button(pos,
				     pp::Vec2d(300, 40), 
				     "button_label", 
				     _("Audio") );
    mp_audioBtn->setHilitFontBinding( "button_label_hilit" );
	mp_audioBtn->signalClicked.Connect(pp::CreateSlot(this,&Configuration::audio));	

	mp_keyboardBtn = new pp::Button(pos,
				     pp::Vec2d(300, 40), 
				     "button_label", 
				     _("Keyboard") );
   	mp_keyboardBtn->setHilitFontBinding( "button_label_hilit" );
	mp_keyboardBtn->signalClicked.Connect(pp::CreateSlot(this,&Configuration::keyboard));	

    mp_backBtn = new pp::Button(pos,
				     pp::Vec2d(300, 40), 
				     "button_label", 
				     _("Back") );
    mp_backBtn->setHilitFontBinding( "button_label_hilit" );
    mp_backBtn->signalClicked.Connect(pp::CreateSlot(this,&Configuration::back));		
}

Configuration::~Configuration()
{
	delete mp_graphicsBtn;
	delete mp_videoBtn;
	delete mp_audioBtn;
	delete mp_keyboardBtn;
	delete mp_backBtn;
}

void
Configuration::loop(double timeStep)
{
	update_audio();
    set_gl_options( GUI );
    clear_rendering_context();
    UIMgr.setupDisplay();
    if (getparam_ui_snow()) {
		update_ui_snow( timeStep, false );
		draw_ui_snow();
    }
	theme.drawMenuDecorations();
	setWidgetPositions();
    UIMgr.draw();
    reshape( getparam_x_resolution(), getparam_y_resolution() );
    winsys_swap_buffers();	
}

void
Configuration::setWidgetPositions()
{
	int w = getparam_x_resolution();
    int h = getparam_y_resolution();
	
	pp::Vec2d pos(w/2,h/2+100);

	Font font("heading",true,true);
	font.draw(mp_heading, pos);
	
	pos.x-=150;
	pos.y-=100;
	mp_graphicsBtn->setPosition(pos);
	pos.y-=40;
	mp_videoBtn->setPosition(pos);
	pos.y-=40;
	mp_audioBtn->setPosition(pos);
	pos.y-=40;
	mp_keyboardBtn->setPosition(pos);
	pos.y-=40;
	mp_backBtn->setPosition(pos);	
}

bool
Configuration::keyPressEvent(unsigned int key)
{
	switch (key){
		case 27:
		case 'q':
			back();
	    	return true;
	}	
	return false;
}

void
Configuration::back()
{
	set_game_mode( preConfigMode );
	preConfigMode = NO_MODE;
    UIMgr.setDirty();
}

void
Configuration::graphics()
{
	set_game_mode( CONFIG_GRAPHICS );
    UIMgr.setDirty();
}

void
Configuration::video()
{
	set_game_mode( CONFIG_VIDEO );
    UIMgr.setDirty();
}

void
Configuration::audio()
{
	set_game_mode( CONFIG_AUDIO );
    UIMgr.setDirty();
}

void
Configuration::keyboard()
{
	set_game_mode( CONFIG_KEYBOARD );
    UIMgr.setDirty();
}
