/* 
 * PPRacer 
 * Copyright (C) 2004 Volker Stroebel <volker@planetpenguin.de>
 *
 * Copyright (C) 1999-2001 Jasmin F. Patry
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "event_select.h"

#include "ppgltk/ui_mgr.h"
#include "ppgltk/ui_theme.h"
#include "ppgltk/button.h"
#include "ppgltk/listbox.h"
#include "ppgltk/ui_snow.h"

#include "ppgltk/audio/audio.h"

#include "loop.h"
#include "render_util.h"
#include "gl_util.h"
#include "course_load.h"
#include "fonts.h"
#include "textures.h"
#include "joystick.h"

#include "game_config.h"

#include "player.h"
#include "game_mgr.h"
	
EventSelect::EventSelect()
{
	pp::Vec2d pos(0,0);
	
	if(GameMode::prevmode==EVENT_RACE_SELECT){
		m_curEvent = gameMgr->currentEvent;
		m_curCup = gameMgr->currentCup;
		if(players[0].isCupComplete((*m_curEvent).name,(*m_curCup).name)){
			if(m_curCup != --(*m_curEvent).cupList.end()){
				m_curCup++;
			}				
		}
	}else{
		m_curEvent = eventList.begin();
		m_curCup = (*m_curEvent).cupList.begin();
	}
	updateCupStates();	
		
	mp_backBtn = new pp::Button( pos,
			      pp::Vec2d(150, 40), 
			      "button_label", 
			      _("Back") );
    mp_backBtn->setHilitFontBinding( "button_label_hilit" );
    mp_backBtn->signalClicked.Connect(pp::CreateSlot(this,&EventSelect::back));

    mp_continueBtn = new pp::Button( pos,
			       pp::Vec2d(150, 40),
			       "button_label",
			       _("Continue") );
    mp_continueBtn->setHilitFontBinding( "button_label_hilit" );
    mp_continueBtn->setDisabledFontBinding( "button_label_disabled" );
    mp_continueBtn->signalClicked.Connect(pp::CreateSlot(this,&EventSelect::apply));

	mp_eventListbox = new pp::Listbox<EventData>( pos,
				   pp::Vec2d(400, 40),
				   "listbox_item",
				   eventList);
	mp_eventListbox->setCurrentItem( m_curEvent );
	mp_eventListbox->signalChange.Connect(pp::CreateSlot(this,&EventSelect::eventChanged));
	
	mp_cupListbox = new pp::Listbox<CupData>( pos,
				   pp::Vec2d(400, 40),
				   "listbox_item",
				   (*m_curEvent).cupList );
	mp_cupListbox->setCurrentItem( m_curCup );	
    mp_cupListbox->signalChange.Connect(pp::CreateSlot(this,&EventSelect::cupChanged));

	updateButtonEnabledStates();
}

EventSelect::~EventSelect()
{
	delete mp_backBtn;
	delete mp_continueBtn;	
	delete mp_eventListbox;
	delete mp_cupListbox;
}

void
EventSelect::loop(double timeStep)
{
    update_audio();
    set_gl_options( GUI );
    clear_rendering_context();
    UIMgr.setupDisplay();
    if (getparam_ui_snow()) {
		update_ui_snow( timeStep, false );
		draw_ui_snow();
    }
    theme.drawMenuDecorations();
    setWidgetPositions();
    UIMgr.draw();
    reshape( getparam_x_resolution(), getparam_y_resolution() );
    winsys_swap_buffers();
}

void
EventSelect::setWidgetPositions()
{
    int width = getparam_x_resolution();
    int height = getparam_y_resolution();
    
	pp::Vec2d pos(width/2,height/2);
	
	mp_backBtn->setPosition(pp::Vec2d(pos.x-250,pos.y-240));
	mp_continueBtn->setPosition(pp::Vec2d(pos.x+50,pos.y-240));
	
	{
		pos.y+=100;
		Font font("menu_label",true,true);
		font.draw(_("Select event and cup"),pos);
	}
	
	{
		pos.y-=60;
		Font font("event_and_cup_label");
		font.draw(_("Event:"),pp::Vec2d(pos.x-200,pos.y));
	
		pos.y-=50;
		mp_eventListbox->setPosition(pp::Vec2d(pos.x-200,pos.y));
	
		pos.y-=40;
		font.draw(_("Cup:"),pp::Vec2d(pos.x-200,pos.y));
	
		pos.y-=50;
		mp_cupListbox->setPosition(pp::Vec2d(pos.x-200,pos.y));
	}
	
	{
	    const char* string;
		if(m_curCupComplete){
			string = _("You've won this cup!");
		}else if (m_curCupPlayable){
			string = _("You must complete this cup next");
		}else{
			string = _("You cannot enter this cup yet"); 
		}
				
		pos.y-=20;
		Font font("cup_status",true,true);
		font.draw(string,pp::Vec2d(pos.x,pos.y));
	}
}

void
EventSelect::updateCupStates()
{
	m_curCupComplete=false;
	m_curCupPlayable=false;
	
	if ( players[0].isCupComplete( (*m_curEvent).name, (*m_curCup).name) ) {
		m_curCupComplete=true;
		m_curCupPlayable=true;
    } else if ( players[0].isFirstIncompleteCup( m_curEvent, m_curCup ) ) {
		m_curCupPlayable=true;
    }
}

void
EventSelect::updateButtonEnabledStates()
{
	if(m_curCupPlayable){
		mp_continueBtn->setEnabled(true);
	}else{
		mp_continueBtn->setEnabled(false);
	}
}

void
EventSelect::cupChanged()
{
	m_curCup = mp_cupListbox->getCurrentItem();
	updateCupStates();
	updateButtonEnabledStates();
}

void
EventSelect::eventChanged()
{
	m_curEvent = mp_eventListbox->getCurrentItem();
	m_curCup = (*m_curEvent).cupList.begin();
	updateCupStates();
	updateButtonEnabledStates();
}

void
EventSelect::back()
{
	set_game_mode( GAME_TYPE_SELECT );
	UIMgr.setDirty();
}

void
EventSelect::apply()
{
    m_curEvent = mp_eventListbox->getCurrentItem();
	m_curCup = mp_cupListbox->getCurrentItem();

	gameMgr->setupEventAndCup(	m_curEvent,
								m_curCup );

	if(!getparam_always_save_event_race_data()){	
	if(!players[0].isCupComplete((*m_curEvent).name, (*m_curCup).name )){
		players[0].clearCupData((*m_curEvent).name, (*m_curCup).name);
	}
	}
	players[0].resetLives();
    set_game_mode( EVENT_RACE_SELECT );
    UIMgr.setDirty();
}

bool
EventSelect::keyPressEvent(SDLKey key)
{
	switch (key){
		case SDLK_UP:
			mp_cupListbox->gotoPrevItem();
	    	return true;
		case SDLK_DOWN:
			mp_cupListbox->gotoNextItem();
	    	return true;
		case SDLK_LEFT:
			mp_eventListbox->gotoPrevItem();
	    	return true;
		case SDLK_RIGHT:
			mp_eventListbox->gotoPrevItem();
	    	return true;
		case SDLK_RETURN: 
	    	mp_continueBtn->simulateMouseClick();
			UIMgr.setDirty();
			return true;
		case SDLK_ESCAPE: 
	    	mp_backBtn->simulateMouseClick();
			UIMgr.setDirty();
			return true;
		default:
			return false;
	}	
}
