/* 
 * PPRacer 
 * Copyright (C) 2004 Volker Stroebel <volker@planetpenguin.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef LISTBOX_H
#define LISTBOX_H

#include "widget.h"
#include "button.h"

#include <list>

namespace pp {


template <class T>
class Listbox : public Widget {
	double arrow_width;
    double border_width;
    double text_pad;
    double arrow_vert_separation;
    char *font_binding;
    pp::Color borderColor;
    pp::Color backgroundColor;
    pp::Button *up_button;
    pp::Button *down_button;
	
	typedef typename std::list<T> list_type;
	typedef typename std::list<T>::iterator list_iterator; 
	
	list_type& items;
	list_iterator cur_item;
	
	void updateButtonEnabledStates();
	void updateButtonPositions();

public:
	Listbox( pp::Vec2d pos, pp::Vec2d size, 
			   char *font_binding, list_type& item_list);	
	~Listbox();

	void setPosition(pp::Vec2d pos);
	void setCurrentItem( list_iterator item );
	list_iterator getCurrentItem(){return cur_item;};
	void setItemList( list_type& item_list );
	
	bool gotoNextItem();
	bool gotoPrevItem();
	
	void upButtonClick();
	void downButtonClick();
	
	void draw();
	
	//signals
	pp::Signal0 signalChange;
};

} //namespace pp

#include "listbox.cpp"

#endif // LISTBOX_H
